@@ -19,39 +19,44 @@ class IvyBloomAPIClient:
     def __init__(self, config: Config, auth_manager: AuthManager):
         self.config = config
         self.auth_manager = auth_manager
-        # Resolve base URL via config with env var overrides
-        self.base_url = config.get_api_url()
+        # Use frontend URL for all API calls - frontend handles Clerk auth and proxying
+        self.base_url = config.get_frontend_url()
         self.timeout = config.get('timeout', 30)
         
-        # Initialize HTTP client
+        # Initialize HTTP client with cookie support and redirect following
         self.client = httpx.Client(
             base_url=self.base_url,
             timeout=self.timeout,
-            headers=self._get_default_headers()
+            headers=self._get_default_headers(),
+            follow_redirects=True,
+            cookies={}  # Enable cookie jar for session management
         )
     
     def _ensure_authenticated(self) -> None:
         """Ensure user is authenticated before making requests"""
-        if not self.auth_manager.is_authenticated():
+        api_key = self.auth_manager.get_api_key()
+        if not api_key:
             raise Exception(
-                "Authentication required. Please run 'ivybloom auth login' first.\n"
-                "You can create an API key at: https://ivybiosciences.com/settings/api-keys"
+                "Authentication required. Please run 'ivybloom auth link' to link your CLI to your account.\n"
+                "Alternatively, you can run 'ivybloom auth login --api-key' with a manual API key."
             )
     
     def _get_default_headers(self) -> Dict[str, str]:
         """Get default headers for requests"""
+        # Build default headers including auth; prefer JWT/OAuth, fallback to API key
         headers = {
             "Content-Type": "application/json",
-            "User-Agent": "ivybloom-cli/0.2.5"
+            "User-Agent": "ivybloom-cli/0.4.1",
+            "Accept": "application/json"
         }
+        # Add Authorization header via AuthManager (JWT/OAuth/API key)
+        headers.update(self.auth_manager.get_auth_headers())
         
-        # Add authentication headers (this will auto-refresh tokens if needed)
-        auth_headers = self.auth_manager.get_auth_headers()
-        headers.update(auth_headers)
-        # Include client identifier for backend linking and analytics
+        # Include client identifier for analytics and linking
         try:
             client_id = self.config.get_or_create_client_id()
-            headers["X-IvyBloom-Client"] = client_id
+            # Prefer lowercase header for compatibility with Node/edge middleware
+            headers["x-ivybloom-client"] = client_id
         except Exception:
             pass
         
@@ -59,14 +64,22 @@ class IvyBloomAPIClient:
     
     def _refresh_headers(self):
         """Refresh authentication headers (for retry logic)"""
-        auth_headers = self.auth_manager.get_auth_headers()
-        self.client.headers.update(auth_headers)
+        # Get fresh headers including updated Clerk session
+        fresh_headers = self._get_default_headers()
+        self.client.headers.update(fresh_headers)
     
     def _make_request(self, method: str, endpoint: str, **kwargs) -> httpx.Response:
         """Make HTTP request with error handling"""
         try:
             # Ensure endpoint joins correctly with base_url
             path = endpoint if endpoint.startswith("/") else f"/{endpoint}"
+            
+            # Ensure headers are fresh for this request
+            self._refresh_headers()
+            
+            if self.config.get('debug'):
+                console.print(f"[dim]{method} {endpoint} -> (sending request)[/dim]")
+            
             response = self.client.request(method, path, **kwargs)
             
             if self.config.get('debug'):
@@ -207,14 +220,65 @@ class IvyBloomAPIClient:
             return {"success": True}
     
     # CLI-specific API methods
-    def list_tools(self) -> List[str]:
-        """List available tools"""
-        data = self.get("/cli/tools")
+    def list_tools(self, verbose: bool = False) -> List[Dict[str, Any]]:
+        """List available tools
+        
+        Args:
+            verbose: If True, request extended/verbose fields from the API
+        
+        Returns:
+            List of tool summaries (render-safe fields by default)
+        """
+        params = {"verbose": True} if verbose else None
+        data = self.get("/api/cli/tools", params=params)
         return data
     
     def get_tool_schema(self, tool_name: str) -> Dict[str, Any]:
-        """Get schema for a specific tool"""
-        return self.get(f"/cli/tools/{tool_name}/schema")
+        """Get schema for a specific tool using the verbose tools list.
+        
+        First attempts to use the per-tool schema endpoint if available.
+        Falls back to loading the verbose tools list and extracting the schema.
+        """
+        # 1) Try direct endpoint if present
+        try:
+            return self.get(f"/api/cli/tools/{tool_name}/schema")
+        except Exception:
+            # Fallback to verbose tools listing
+            pass
+
+        tools_verbose = self.list_tools(verbose=True)
+        if not isinstance(tools_verbose, list):
+            raise Exception("Unexpected response while loading tools list for schema")
+        
+        def normalize(value: Any) -> str:
+            return str(value).strip().lower() if value is not None else ""
+        target = tool_name.strip().lower()
+        
+        for tool in tools_verbose:
+            if not isinstance(tool, dict):
+                continue
+            candidates = [
+                normalize(tool.get("name")),
+                normalize(tool.get("id")),
+                normalize(tool.get("tool")),
+                normalize(tool.get("slug")),
+            ]
+            if target in candidates:
+                schema_obj = tool.get("schema") or tool.get("parameters")
+                if isinstance(schema_obj, dict):
+                    return schema_obj
+                if isinstance(schema_obj, str):
+                    try:
+                        return json.loads(schema_obj)
+                    except Exception:
+                        pass
+                # Minimal fallback when schema not present but metadata exists
+                return {
+                    "description": tool.get("description", ""),
+                    "parameters": {},
+                }
+        
+        raise Exception(f"Schema for tool '{tool_name}' not found in tools list")
     
     def create_job(self, job_request: Dict[str, Any]) -> Dict[str, Any]:
         """Create a new job"""
@@ -230,12 +294,12 @@ class IvyBloomAPIClient:
         # Remove None values to keep payload clean
         payload = {k: v for k, v in payload.items() if v is not None}
         
-        return self.post("/cli/jobs", json_data=payload)
+        return self.post("/api/cli/jobs", json_data=payload)
     
     def get_job_status(self, job_id: str, include_logs: bool = False) -> Dict[str, Any]:
         """Get job status"""
         params = {"include_logs": include_logs} if include_logs else None
-        response = self.get(f"/cli/jobs/{job_id}", params=params)
+        response = self.get(f"/api/cli/jobs/{job_id}", params=params)
         
         # Map database field names to CLI-expected field names for backward compatibility
         if response and 'id' in response:
@@ -250,7 +314,7 @@ class IvyBloomAPIClient:
     def get_job_results(self, job_id: str, format: str = "json") -> Dict[str, Any]:
         """Get job results"""
         params = {"format": format}
-        response = self.get(f"/cli/jobs/{job_id}/results", params=params)
+        response = self.get(f"/api/cli/jobs/{job_id}/results", params=params)
         
         # Map database field names for consistency
         if response and 'id' in response:
@@ -262,7 +326,7 @@ class IvyBloomAPIClient:
     
     def cancel_job(self, job_id: str) -> Dict[str, Any]:
         """Cancel a job"""
-        return self.delete(f"/cli/jobs/{job_id}")
+        return self.delete(f"/api/cli/jobs/{job_id}")
     
     def get_job_download_urls(self, job_id: str, artifact_type: str = None) -> Dict[str, Any]:
         """Get presigned download URLs for job artifacts"""
@@ -270,7 +334,7 @@ class IvyBloomAPIClient:
         if artifact_type:
             params['artifact_type'] = artifact_type
         
-        return self.get("/cli/download", params=params)
+        return self.get("/api/cli/download", params=params)
     
     def list_jobs(self, **filters) -> List[Dict[str, Any]]:
         """List jobs with optional filters"""
@@ -291,35 +355,50 @@ class IvyBloomAPIClient:
         if 'offset' in filters and filters['offset']:
             params['offset'] = filters['offset']
         
-        return self.get("/cli/jobs", params=params)
+        return self.get("/api/cli/jobs", params=params)
     
     def list_projects(self) -> List[Dict[str, Any]]:
         """List user's projects"""
-        return self.get("/cli/projects")
+        return self.get("/api/cli/projects")
     
     def get_project(self, project_id: str) -> Dict[str, Any]:
         """Get project details"""
-        return self.get(f"/cli/projects/{project_id}")
+        return self.get(f"/api/cli/projects/{project_id}")
     
     def list_project_jobs(self, project_id: str) -> List[Dict[str, Any]]:
         """List jobs for a specific project"""
-        return self.get(f"/cli/projects/{project_id}/jobs")
+        return self.get(f"/api/cli/projects/{project_id}/jobs")
     
     def get_account_info(self) -> Dict[str, Any]:
         """Get account information"""
-        return self.get("/cli/account")
+        return self.get("/api/cli/account")
     
     def get_usage_stats(self) -> Dict[str, Any]:
         """Get usage statistics"""
-        return self.get("/cli/usage")
+        return self.get("/api/cli/usage")
     
     def check_cli_linking_status(self, client_id: str) -> Dict[str, Any]:
-        """Check if CLI client is linked to a user account"""
-        return self.get(f"/cli/link-status/{client_id}")
+        """Check if CLI client is linked to a user account
+        
+        Returns:
+            Dict with 'linked' boolean and optionally 'ready' boolean.
+            - linked: True if the client is linked to a user account
+            - ready: True if the temporary API key is ready for retrieval (newer deployments)
+                    If absent, fallback to legacy behavior (older deployments)
+        """
+        return self.get(f"/api/cli/link-status/{client_id}")
     
     def verify_cli_linking(self, client_id: str) -> Dict[str, Any]:
-        """Verify and complete CLI linking process"""
-        return self.post(f"/cli/verify-link/{client_id}")
+        """Verify and complete CLI linking process
+        
+        Should only be called when linked=True AND ready=True (if ready flag is present)
+        to avoid 410 "expired/already retrieved" responses.
+        
+        Returns:
+            Dict with 'success' boolean and 'api_key' string on success.
+            May return 410 if temp key is missing/expired/already retrieved.
+        """
+        return self.post(f"/api/cli/verify-link/{client_id}")
     
     # Missing API endpoints for other CLI commands
     def list_workflows(self, **filters) -> List[Dict[str, Any]]:
@@ -338,20 +417,20 @@ class IvyBloomAPIClient:
         if 'sort_order' in filters and filters['sort_order']:
             params['sort_order'] = filters['sort_order']
         
-        return self.get("/cli/workflows", params=params)
+        return self.get("/api/cli/workflows", params=params)
     
     def get_workflow(self, workflow_id: str) -> Dict[str, Any]:
         """Get workflow details"""
-        return self.get(f"/cli/workflows/{workflow_id}")
+        return self.get(f"/api/cli/workflows/{workflow_id}")
     
     def create_workflow(self, workflow_data: Dict[str, Any]) -> Dict[str, Any]:
         """Create a new workflow"""
-        return self.post("/cli/workflows", json_data=workflow_data)
+        return self.post("/api/cli/workflows", json_data=workflow_data)
     
     def execute_workflow(self, workflow_id: str, parameters: Dict[str, Any] = None) -> Dict[str, Any]:
         """Execute a workflow"""
         payload = {"parameters": parameters or {}}
-        return self.post(f"/cli/workflows/{workflow_id}/execute", json_data=payload)
+        return self.post(f"/api/cli/workflows/{workflow_id}/execute", json_data=payload)
     
     def list_data_files(self, **filters) -> List[Dict[str, Any]]:
         """List data files with optional filters"""
@@ -371,27 +450,27 @@ class IvyBloomAPIClient:
         if 'sort_order' in filters and filters['sort_order']:
             params['sort_order'] = filters['sort_order']
         
-        return self.get("/cli/data", params=params)
+        return self.get("/api/cli/data", params=params)
     
     def upload_data_file(self, file_data: Dict[str, Any]) -> Dict[str, Any]:
         """Upload a data file"""
-        return self.post("/cli/data/upload", json_data=file_data)
+        return self.post("/api/cli/data/upload", json_data=file_data)
     
     def get_data_file(self, file_id: str) -> Dict[str, Any]:
         """Get data file details"""
-        return self.get(f"/cli/data/{file_id}")
+        return self.get(f"/api/cli/data/{file_id}")
     
     def delete_data_file(self, file_id: str) -> Dict[str, Any]:
         """Delete a data file"""
-        return self.delete(f"/cli/data/{file_id}")
+        return self.delete(f"/api/cli/data/{file_id}")
     
     def get_config_settings(self) -> Dict[str, Any]:
         """Get CLI configuration settings from backend"""
-        return self.get("/cli/config")
+        return self.get("/api/cli/config")
     
     def update_config_settings(self, settings: Dict[str, Any]) -> Dict[str, Any]:
         """Update CLI configuration settings"""
-        return self.post("/cli/config", json_data=settings)
+        return self.post("/api/cli/config", json_data=settings)
     
     def close(self):
         """Close the HTTP client"""
