@@ -327,6 +327,121 @@ def link(ctx, open_browser, frontend_url, no_wait):
         console.print("   Complete the linking process in your browser.")
         console.print("   Run 'ivybloom auth status' to check if linking was successful.")
 
+@auth.command()
+@click.argument('client_id', required=False)
+@click.option('--frontend-url', help='Override frontend URL for testing')
+def debug_link(client_id, frontend_url):
+    """🔍 Debug CLI linking endpoints for troubleshooting
+    
+    Test the CLI linking endpoints to diagnose connection issues.
+    If no client_id is provided, generates a test UUID.
+    
+    USAGE:
+      ivybloom auth debug-link                    # Test with random client ID
+      ivybloom auth debug-link YOUR_CLIENT_ID     # Test with specific client ID
+    
+    This command helps diagnose:
+      • Domain redirect issues (308 responses)
+      • WAF/Cloudflare blocking (403 responses)
+      • Endpoint availability (404 responses)
+      • Network connectivity issues
+    """
+    import httpx
+    import uuid
+    from rich.table import Table
+    
+    config = Config()
+    
+    # Use provided client_id or generate test one
+    test_client_id = client_id or str(uuid.uuid4())
+    resolved_frontend = frontend_url or config.get_frontend_url()
+    
+    console.print(f"\n🔍 [yellow]Testing CLI linking endpoints...[/yellow]")
+    console.print(f"   Frontend URL: [cli.bright]{resolved_frontend}[/cli.bright]")
+    console.print(f"   Test Client ID: [cli.accent]{test_client_id}[/cli.accent]")
+    console.print()
+    
+    # Test table
+    table = Table(title="🧪 CLI Linking Endpoint Tests")
+    table.add_column("Endpoint", style="cyan")
+    table.add_column("Status", style="magenta")
+    table.add_column("Response", style="green")
+    table.add_column("Notes", style="yellow")
+    
+    # Test link-status endpoint
+    status_url = f"{resolved_frontend.rstrip('/')}/api/cli/link-status/{test_client_id}"
+    try:
+        with httpx.Client(follow_redirects=True, timeout=10.0) as client:
+            response = client.get(status_url, headers={
+                "User-Agent": "ivybloom-cli/0.3.4",
+                "Accept": "application/json"
+            })
+            
+            redirects = len(response.history) if hasattr(response, 'history') else 0
+            redirect_note = f" ({redirects} redirects)" if redirects > 0 else ""
+            
+            if response.status_code == 200:
+                try:
+                    data = response.json()
+                    table.add_row("link-status", "✅ 200", str(data), f"Success{redirect_note}")
+                except:
+                    table.add_row("link-status", "✅ 200", "Non-JSON response", f"Unexpected format{redirect_note}")
+            elif response.status_code == 401:
+                table.add_row("link-status", "🔐 401", "Unauthorized", f"Endpoint exists, auth required{redirect_note}")
+            elif response.status_code == 404:
+                table.add_row("link-status", "❌ 404", "Not Found", f"Endpoint missing{redirect_note}")
+            elif response.status_code == 403:
+                table.add_row("link-status", "🚫 403", "Forbidden", f"WAF/Cloudflare blocking{redirect_note}")
+            else:
+                table.add_row("link-status", f"⚠️ {response.status_code}", response.reason_phrase or "Unknown", f"Unexpected response{redirect_note}")
+                
+    except Exception as e:
+        table.add_row("link-status", "💥 ERROR", str(e), "Network/connection issue")
+    
+    # Test verify-link endpoint  
+    verify_url = f"{resolved_frontend.rstrip('/')}/api/cli/verify-link/{test_client_id}"
+    try:
+        with httpx.Client(follow_redirects=True, timeout=10.0) as client:
+            response = client.post(verify_url, headers={
+                "User-Agent": "ivybloom-cli/0.3.4",
+                "Accept": "application/json",
+                "Content-Type": "application/json"
+            })
+            
+            redirects = len(response.history) if hasattr(response, 'history') else 0
+            redirect_note = f" ({redirects} redirects)" if redirects > 0 else ""
+            
+            if response.status_code == 200:
+                table.add_row("verify-link", "✅ 200", "Success", f"Endpoint working{redirect_note}")
+            elif response.status_code == 404:
+                table.add_row("verify-link", "❌ 404", "Not Found", f"Client not linked{redirect_note}")
+            elif response.status_code == 410:
+                table.add_row("verify-link", "⏰ 410", "Gone", f"Temp key expired/missing{redirect_note}")
+            elif response.status_code == 401:
+                table.add_row("verify-link", "🔐 401", "Unauthorized", f"Endpoint exists, auth required{redirect_note}")
+            elif response.status_code == 403:
+                table.add_row("verify-link", "🚫 403", "Forbidden", f"WAF/Cloudflare blocking{redirect_note}")
+            else:
+                table.add_row("verify-link", f"⚠️ {response.status_code}", response.reason_phrase or "Unknown", f"Unexpected response{redirect_note}")
+                
+    except Exception as e:
+        table.add_row("verify-link", "💥 ERROR", str(e), "Network/connection issue")
+    
+    console.print(table)
+    console.print()
+    
+    # Recommendations
+    console.print("💡 [yellow]Troubleshooting Tips:[/yellow]")
+    console.print("   • 401/404 responses are normal for test client IDs")
+    console.print("   • 403 responses suggest WAF/Cloudflare blocking")
+    console.print("   • Multiple redirects may cause issues - check frontend URL")
+    console.print("   • Network errors suggest connectivity issues")
+    console.print()
+    console.print("🔧 [yellow]For WAF issues, whitelist:[/yellow]")
+    console.print("   • Path prefix: [cli.accent]/api/cli/*[/cli.accent]")
+    console.print("   • User-Agent: [cli.accent]ivybloom-cli*[/cli.accent]")
+    console.print()
+
 @auth.command()
 @click.option('--confirm', is_flag=True, help='Skip confirmation prompt')
 @click.pass_context
@@ -485,7 +600,7 @@ def _wait_for_cli_linking(config: Config, auth_manager: AuthManager, client_id:
         )
         
         start_time = time.time()
-        poll_interval = 3  # Poll every 3 seconds
+        poll_interval = 2.5  # Poll every 2.5 seconds (within 2-3s range)
         
         while time.time() - start_time < timeout:
             elapsed = time.time() - start_time
@@ -495,37 +610,79 @@ def _wait_for_cli_linking(config: Config, auth_manager: AuthManager, client_id:
             progress.update(task, completed=elapsed, remaining=remaining)
             
             try:
-                # Check linking status (this endpoint doesn't require auth)
+                # Check linking status via frontend (avoids backend SSL issues)
                 import httpx
-                api_url = config.get_api_url()
-                status_url = f"{api_url.rstrip('/')}/cli/link-status/{client_id}"
+                frontend_url = config.get_frontend_url()
+                status_url = f"{frontend_url.rstrip('/')}/api/cli/link-status/{client_id}"
                 
-                with httpx.Client() as client:
+                # Configure client with redirect following and timeout
+                with httpx.Client(
+                    follow_redirects=True,
+                    timeout=30.0,
+                    headers={
+                        "User-Agent": "ivybloom-cli/0.3.4",
+                        "Accept": "application/json"
+                    }
+                ) as client:
                     response = client.get(status_url)
                     
                     if response.status_code == 200:
                         status_data = response.json()
                         
                         if status_data.get('linked', False):
-                            # Linking completed! Now verify and get credentials
-                            progress.update(task, description="✅ Linking completed! Verifying...")
-                            time.sleep(0.5)
+                            # Check if ready flag is present (newer deployments)
+                            ready_flag = status_data.get('ready')
                             
-                            # Use direct HTTP request to verify and get auto-generated API key
+                            if ready_flag is not None:
+                                # New behavior: only proceed when ready is true
+                                if ready_flag:
+                                    # Linking completed and ready! Now verify and get credentials
+                                    progress.update(task, description="✅ Linking ready! Verifying...")
+                                    time.sleep(0.5)
+                                else:
+                                    # Linked but not ready yet - continue polling
+                                    progress.update(task, description="⏳ Linked, waiting for API key generation...")
+                                    time.sleep(poll_interval)
+                                    continue
+                            else:
+                                # Fallback behavior for older deployments without ready flag
+                                progress.update(task, description="✅ Linking completed! Verifying...")
+                                time.sleep(0.5)
+                            
+                            # Use frontend endpoint to verify and get auto-generated API key
                             try:
-                                verify_url = f"{api_url.rstrip('/')}/cli/verify-link/{client_id}"
-                                headers = {
+                                verify_url = f"{frontend_url.rstrip('/')}/api/cli/verify-link/{client_id}"
+                                verify_headers = {
                                     "Content-Type": "application/json",
-                                    "User-Agent": "ivybloom-cli/0.2.5",
-                                    "X-IvyBloom-Client": client_id
+                                    "User-Agent": "ivybloom-cli/0.3.4",
+                                    "x-ivybloom-client": client_id,
+                                    "Accept": "application/json"
                                 }
                                 
-                                verify_response = client.post(verify_url, headers=headers)
+                                # Use a separate client for verify request to ensure proper redirect handling
+                                with httpx.Client(
+                                    follow_redirects=True,
+                                    timeout=30.0
+                                ) as verify_client:
+                                    verify_response = verify_client.post(verify_url, headers=verify_headers)
                                 
-                                if verify_response.status_code >= 400:
+                                if verify_response.status_code == 410:
+                                    # Temp key expired/already retrieved - handle based on ready flag presence
+                                    if ready_flag is not None:
+                                        # New deployment: this shouldn't happen if we waited for ready=true
+                                        # But if it does, it means the key was already consumed
+                                        progress.update(task, description="❌ API key already retrieved or expired!")
+                                        time.sleep(1)
+                                        return False
+                                    else:
+                                        # Older deployment: fallback behavior - retry after short delay
+                                        progress.update(task, description="⏳ API key not ready yet, retrying...")
+                                        time.sleep(2)  # Wait a bit longer before retrying
+                                        continue  # Go back to polling status
+                                elif verify_response.status_code >= 400:
                                     try:
                                         error_data = verify_response.json()
-                                        error_msg = error_data.get('detail', error_data.get('message', f'HTTP {verify_response.status_code}'))
+                                        error_msg = error_data.get('error', error_data.get('detail', error_data.get('message', f'HTTP {verify_response.status_code}')))
                                     except:
                                         error_msg = f'HTTP {verify_response.status_code}'
                                     raise Exception(f"API error: {error_msg}")
@@ -539,9 +696,8 @@ def _wait_for_cli_linking(config: Config, auth_manager: AuthManager, client_id:
                                         progress.update(task, description="✅ API key retrieved and stored!")
                                         time.sleep(0.5)
                                     
-                                    # Also store any auth token if provided (backward compatibility)
-                                    if 'auth_token' in verify_result:
-                                        auth_manager.store_auth_token(verify_result['auth_token'])
+                                    # Note: Frontend handles all Clerk authentication
+                                    # CLI only needs the API key to authenticate with frontend
                                     
                                     return True
                                 else:
@@ -553,14 +709,39 @@ def _wait_for_cli_linking(config: Config, auth_manager: AuthManager, client_id:
                                 progress.update(task, description=f"❌ Verification error: {e}")
                                 time.sleep(1)
                                 return False
+                    elif response.status_code == 308:
+                        # Permanent redirect - this shouldn't happen with follow_redirects=True
+                        progress.update(task, description="⚠️  Redirect detected - retrying...")
+                        time.sleep(1)
+                        continue
+                    elif response.status_code >= 400:
+                        # HTTP error
+                        if response.status_code == 404:
+                            progress.update(task, description="❌ CLI linking endpoint not found!")
+                        elif response.status_code == 403:
+                            progress.update(task, description="⚠️  Access blocked - checking WAF/Cloudflare...")
+                        else:
+                            progress.update(task, description=f"⚠️  HTTP {response.status_code} error - retrying...")
+                        
+                        # Don't fail immediately on HTTP errors - might be temporary
+                        time.sleep(2)
+                        continue
                 
             except KeyboardInterrupt:
                 progress.update(task, description="❌ Cancelled by user!")
                 time.sleep(0.5)
                 return False
-            except Exception:
+            except Exception as e:
                 # Network error or other issue - continue polling
-                pass
+                # But provide some feedback for persistent errors
+                error_str = str(e)
+                if "525" in error_str or "SSL handshake failed" in error_str:
+                    progress.update(task, description="⚠️  Backend SSL issue - retrying...")
+                elif "timeout" in error_str.lower():
+                    progress.update(task, description="⚠️  Network timeout - retrying...")
+                else:
+                    progress.update(task, description="⚠️  Network error - retrying...")
+                # Continue polling despite errors
             
             # Wait before next poll
             time.sleep(poll_interval)
