@@ -19,40 +19,16 @@ console = get_console()
 
 @click.group()
 def workflows():
-    """🔄 Multi-step computational workflow orchestration
-    
-    Execute complex computational pipelines that chain multiple tools together.
-    Perfect for multi-step analyses like drug discovery or protein characterization.
-    
-    WORKFLOW vs SINGLE TOOLS:
-    
-      • Single tool:     ivybloom run esmfold protein_sequence=MKLLVL
-      • Multi-step:      ivybloom workflows run protein_analysis.yaml
-    
-    WORKFLOW CAPABILITIES:
-    
-      🔗 Chain multiple tools in sequence
-      🔀 Run tools in parallel where possible  
-      📊 Automatic data flow between steps
-      ⚙️  Conditional execution based on results
-      📁 Organized output management
-    
-    COMMON WORKFLOWS:
-    
-      • Drug discovery pipeline (screening → docking → ADMET → optimization)
-      • Protein analysis (folding → binding sites → druggability)
-      • Molecular dynamics (preparation → simulation → analysis)
-      • High-throughput screening (batch processing → analysis → ranking)
-    
-    WORKFLOW FILES:
-    
-      Workflows are defined in YAML or JSON files with job definitions,
-      dependencies, and data flow specifications.
-    
-    💡 TIP: Use 'ivybloom workflows create' to generate workflow templates
-    💡 TIP: Use --dry-run to preview workflow execution plan
-    
-    Run 'ivybloom workflows <command> --help' for detailed help on each command.
+    """Compose and run multi-step workflows (WIP)
+
+    - Run:       ivybloom workflows run <file.yaml> [--project-id <id>] [--wait]
+    - Validate:  ivybloom workflows validate <file.yaml>
+    - Template:  ivybloom workflows create <file.yaml> [--format yaml|json]
+    - List:      ivybloom workflows list
+
+    Notes:
+      - Workflow files are YAML/JSON with jobs, depends_on, and data flow.
+      - Use --dry-run to preview execution order and parameters.
     """
     pass
 
@@ -155,7 +131,57 @@ def create(ctx, output_file, format):
 @click.argument('workflow_file', type=click.Path(exists=True))
 @click.pass_context
 def validate(ctx, workflow_file):
-    """Validate a workflow file"""
+    """🔍 Validate workflow file structure and dependencies
+    
+    Perform comprehensive validation of workflow files before execution.
+    This command checks syntax, job dependencies, parameter requirements,
+    and workflow structure to catch errors early and save compute time.
+    
+    VALIDATION CHECKS:
+    
+      ✅ YAML/JSON syntax validation
+      ✅ Required workflow fields (name, jobs)
+      ✅ Job structure and dependencies
+      ✅ Circular dependency detection
+      ✅ Parameter existence checks
+      ✅ Tool name validation
+    
+    WHY VALIDATE FIRST:
+    
+      🚀 Catch errors before expensive computations start
+      💰 Avoid wasted compute credits on malformed workflows
+      🔧 Get specific error messages for quick fixes
+      📋 Ensure workflows meet IvyBloom standards
+      🔗 Verify job dependency chains are valid
+    
+    VALIDATION LEVELS:
+    
+      🔴 ERRORS: Critical issues that prevent execution
+      🟡 WARNINGS: Potential issues that may cause problems
+      🟢 SUCCESS: Workflow is ready for execution
+    
+    USAGE EXAMPLES:
+    
+      # Validate before running expensive workflows
+      ivybloom workflows validate my-drug-discovery.yaml
+      
+      # Quick check after editing workflow files
+      ivybloom workflows validate protein-analysis.yaml
+      
+      # Validate all workflows in current directory
+      for file in *.yaml; do ivybloom workflows validate "$file"; done
+    
+    COMMON VALIDATION ERRORS:
+    
+      • Missing required fields (name, jobs)
+      • Duplicate job names within workflow
+      • Circular dependencies between jobs
+      • References to non-existent job outputs
+      • Invalid tool names or parameters
+    
+    💡 TIP: Always validate workflows after editing before submission!
+    💡 TIP: Use validation in CI/CD pipelines for workflow quality control
+    """
     
     try:
         # Load workflow file
@@ -175,14 +201,14 @@ def validate(ctx, workflow_file):
             errors.append("Missing required field: 'name'")
         if 'jobs' not in workflow:
             errors.append("Missing required field: 'jobs'")
-        elif not isinstance(workflow['jobs'], list):
+        elif not hasattr(workflow['jobs'], '__iter__') or hasattr(workflow['jobs'], 'split'):
             errors.append("Field 'jobs' must be a list")
         
         # Validate jobs
         if 'jobs' in workflow:
             job_names = set()
             for i, job in enumerate(workflow['jobs']):
-                if not isinstance(job, dict):
+                if not hasattr(job, 'get'):
                     errors.append(f"Job {i} must be an object")
                     continue
                 
